@@ -4,6 +4,7 @@ class ChildRuntimeConfig:
         self.enable_remote_debug = False
         self.remote_debug_port = -1
         self.runtime_engine = 'pytest'
+        self.collect_timings = False
 
     def use_engine(self, new_engine):
         self.runtime_engine = new_engine
@@ -12,5 +13,8 @@ class ChildRuntimeConfig:
         self.enable_remote_debug = True
         self.remote_debug_port = int(port_to_use)
 
+    def enable_timing_collection(self):
+        self.collect_timings = True
+
 
 child_config = ChildRuntimeConfig()
