@@ -1,7 +1,5 @@
-from asyncio import Queue
-
-from pycrunch.pipeline.abstract_task import AbstractTask
 import logging
+from asyncio import Queue
 
 logger = logging.getLogger(__name__)
 
@@ -10,12 +8,18 @@ class ExecutionPipeline:
     def __init__(self):
         self.q = Queue()
 
-    def add_task(self, task):
+    def add_task(self, task: "AbstractTask"):
         logger.debug('Received task in queue')
         self.q.put_nowait(task)
 
+    def tasks_in_queue(self):
+        return self.q.qsize()
+
     async def get_task(self):
         return await self.q.get()
 
+    async def put_raw(self, abstract_task):
+        await self.q.put(abstract_task)
 
-execution_pipeline = ExecutionPipeline()
\ No newline at end of file
+
+execution_pipeline = ExecutionPipeline()
