@@ -6,11 +6,11 @@ class HandshakeMessage(AbstractMessage):
     def __init__(self, task_id):
         self.task_id = task_id
         self.kind = 'handshake'
-        # self.bytes_junk = bytearray(998765)
 
 class ScheduledTaskDefinitionMessage(AbstractMessage):
-    def __init__(self, task):
+    def __init__(self, task, coverage_exclusions):
         self.task = task
+        self.coverage_exclusions = coverage_exclusions  # type: list[str]
         self.kind = 'test-run-task'
 
 class TestResultsAvailableMessage(AbstractMessage):
